:orphan:

************
Installation
************

.. start installation

Package ``ut-arr`` can be installed from PyPI or Anaconda.

To install with ``pip``:

.. code-block:: shell

   $ python -m pip install ut-arr

To install with ``conda``:

.. code-block:: shell

   $ conda install -c conda-forge ut-arr

.. end installation
